@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 from gdsfactory.export.to_3d import to_3d
+from gdsfactory.export.to_gerber import to_gerber
 from gdsfactory.export.to_np import to_np
 from gdsfactory.export.to_stl import to_stl
 
-__all__ = ("to_3d", "to_stl", "to_np")
+__all__ = ("to_3d", "to_gerber", "to_np", "to_stl")
