@@ -1,18 +1,21 @@
 from __future__ import annotations
 
+from typing import cast
+
 import shapely
+from kfactory import LayerEnum
 from trimesh.scene.scene import Scene
 
 from gdsfactory.component import Component
 from gdsfactory.technology import DerivedLayer, LayerStack, LayerViews, LogicalLayer
-from gdsfactory.typings import LayerSpec
+from gdsfactory.typings import LayerSpecs
 
 
 def to_3d(
     component: Component,
     layer_views: LayerViews | None = None,
     layer_stack: LayerStack | None = None,
-    exclude_layers: tuple[LayerSpec, ...] | None = None,
+    exclude_layers: LayerSpecs | None = None,
 ) -> Scene:
     """Return Component 3D trimesh Scene.
 
@@ -56,16 +59,16 @@ def to_3d(
         layer = level.layer
 
         if isinstance(layer, LogicalLayer):
-            layer_index = layer.layer
-            layer_tuple = tuple(layer_index)
-
+            assert isinstance(layer.layer, tuple | LayerEnum)
+            layer_tuple = cast(tuple[int, int], tuple(layer.layer))
         elif isinstance(layer, DerivedLayer):
-            layer_index = level.derived_layer.layer
-            layer_tuple = tuple(layer_index)
+            assert level.derived_layer is not None
+            assert isinstance(level.derived_layer.layer, tuple | LayerEnum)
+            layer_tuple = cast(tuple[int, int], tuple(level.derived_layer.layer))
         else:
             raise ValueError(f"Layer {layer!r} is not a DerivedLayer or LogicalLayer")
 
-        layer_index = int(get_layer(layer_index))
+        layer_index = int(get_layer(layer_tuple))
 
         if layer_index in exclude_layers:
             continue
@@ -75,6 +78,7 @@ def to_3d(
 
         zmin = level.zmin
         layer_view = layer_views.get_from_tuple(layer_tuple)
+        assert layer_view.fill_color is not None
         color_rgb = [c / 255 for c in layer_view.fill_color.as_rgb_tuple(alpha=False)]
         if zmin is not None and layer_view.visible:
             has_polygons = True
@@ -95,15 +99,18 @@ def to_3d(
 
 
 if __name__ == "__main__":
-    import gdsfactory as gf
+    from gdsfactory.components import (
+        grating_coupler_elliptical_trenches,
+    )
 
     # c = gf.components.mzi()
     # c = gf.components.straight_heater_metal(length=40)
     # p = c.get_polygons_points()
     # c = gf.Component()
     # c << gf.c.rectangle(layer=(113, 0))
-    c = gf.components.grating_coupler_elliptical_trenches()
-    # c = gf.components.taper_strip_to_ridge_trenches()
+
+    c = grating_coupler_elliptical_trenches()
+    # c = taper_strip_to_ridge_trenches()
 
     c.show()
     s = c.to_3d()
