@@ -902,6 +902,7 @@ def extrude(
     """
     from gdsfactory.pdk import get_cross_section, get_layer
 
+    x = None
     if cross_section is None and layer is None:
         raise ValueError("CrossSection or layer needed")
 
@@ -910,7 +911,10 @@ def extrude(
 
     if layer is not None and width is None:
         raise ValueError("Need to define layer width")
-    elif width:
+    elif width and cross_section:
+        x = get_cross_section(cross_section, width=width)
+
+    elif width and layer:
         assert layer is not None
         s = Section(
             width=width,
@@ -925,7 +929,8 @@ def extrude(
 
     assert cross_section is not None
 
-    x = get_cross_section(cross_section)
+    if x is None:
+        x = get_cross_section(cross_section)
 
     layer = layer or x.layer
     layer = get_layer(layer)
@@ -1479,12 +1484,43 @@ def _fresnel(
     return np.sqrt(2) * R0 * x, np.sqrt(2) * R0 * y
 
 
+def _fresnel_angular(
+    R0: float, s: float, num_pts: int, n_iter: int = 8
+) -> tuple[npt.NDArray[np.floating[Any]], npt.NDArray[np.floating[Any]]]:
+    """Fresnel integral with uniform angular sampling.
+
+    Args:
+        R0: Initial radius of curvature.
+        s: Length of the curve.
+        num_pts: Number of points to generate.
+        n_iter: Number of iterations to use in the series expansion.
+    """
+    # For Fresnel spiral, the angle theta = t^2/2
+    # So t = sqrt(2*theta), where theta is in radians
+    t_max = s / float(np.sqrt(2) * R0)
+    theta_max = t_max**2 / 2
+
+    # Generate uniform angles
+    thetas = np.linspace(0, theta_max, num_pts)
+    t = np.sqrt(2 * thetas)
+
+    x = np.zeros(num_pts)
+    y = np.zeros(num_pts)
+
+    for n in range(n_iter):
+        x += (-1) ** n * t ** (4 * n + 1) / (math.factorial(2 * n) * (4 * n + 1))
+        y += (-1) ** n * t ** (4 * n + 3) / (math.factorial(2 * n + 1) * (4 * n + 3))
+
+    return np.sqrt(2) * R0 * x, np.sqrt(2) * R0 * y
+
+
 def euler(
     radius: float = 10,
     angle: float = 90,
     p: float = 0.5,
     use_eff: bool = False,
     npoints: int | None = None,
+    angular_step: float | None = None,
 ) -> Path:
     """Returns an euler bend that adiabatically transitions from straight to curved.
 
@@ -1502,6 +1538,8 @@ def euler(
                 If True: The curve will be scaled such that the endpoints match an \
                 arc with parameters `radius` and `angle`.
         npoints: Number of points used per 360 degrees.
+        angular_step: If provided, determines the angular step (in degrees) between points. \
+                This overrides npoints calculation.
 
     .. plot::
         :include-source:
@@ -1514,12 +1552,20 @@ def euler(
     """
     from gdsfactory.pdk import get_active_pdk
 
+    if angular_step is not None and npoints is not None:
+        raise ValueError(
+            "euler() requires either npoints or angular_step, not both. "
+            "Use angular_step for angular discretization."
+        )
+
     if not radius:
         raise ValueError("euler() requires a radius argument")
 
     if (p < 0) or (p > 1):
         raise ValueError(f"euler requires argument `p` be between 0 and 1. Got {p}")
     if p == 0:
+        if angular_step is not None:
+            npoints = abs(int(angle / angular_step)) + 1
         path = arc(radius=radius, angle=angle, npoints=npoints)
         path.info["Reff"] = radius
         path.info["Rmin"] = radius
@@ -1538,11 +1584,23 @@ def euler(
     s0 = float(2 * sp + Rp * alpha * (1 - p))
 
     pdk = get_active_pdk()
-    npoints = npoints or abs(int(angle / 360 * radius / pdk.bend_points_distance / 2))
-    npoints = max(npoints, int(360 / angle) + 1)
-
-    num_pts_euler = int(np.round(sp / (s0 / 2) * npoints))
-    num_pts_arc = npoints - num_pts_euler
+    if angular_step is not None:
+        npoints = abs(int(angle / angular_step)) + 1
+        # For angular discretization, distribute points based on angle proportion
+        euler_angle = p * angle / 2  # Angle covered by each Euler section
+        arc_angle = (1 - p) * angle  # Angle covered by arc section
+        num_pts_euler = max(1, int(euler_angle / angular_step))
+        num_pts_arc = max(1, int(arc_angle / angular_step)) + 1
+        npoints = (
+            2 * num_pts_euler + num_pts_arc - 2
+        )  # Total points (avoiding duplicates)
+    else:
+        npoints = npoints or abs(
+            int(angle / 360 * radius / pdk.bend_points_distance / 2)
+        )
+        npoints = max(npoints, int(360 / angle) + 1)
+        num_pts_euler = int(np.round(sp / (s0 / 2) * npoints))
+        num_pts_arc = npoints - num_pts_euler
 
     # Ensure a minimum of 2 points for each euler/arc section
     if npoints <= 2:
@@ -1550,7 +1608,10 @@ def euler(
         num_pts_arc = 2
 
     if num_pts_euler > 0:
-        xbend1, ybend1 = _fresnel(R0, sp, num_pts_euler)
+        if angular_step is not None:
+            xbend1, ybend1 = _fresnel_angular(R0, sp, num_pts_euler)
+        else:
+            xbend1, ybend1 = _fresnel(R0, sp, num_pts_euler)
         xp, yp = xbend1[-1], ybend1[-1]
         dx = xp - Rp * np.sin(p * alpha / 2)
         dy = yp - Rp * (1 - np.cos(p * alpha / 2))
@@ -1559,9 +1620,16 @@ def euler(
         dx = 0
         dy = 0
 
-    s = np.linspace(sp, s0 / 2, num_pts_arc)
-    xbend2 = Rp * np.sin((s - sp) / Rp + p * alpha / 2) + dx
-    ybend2 = Rp * (1 - np.cos((s - sp) / Rp + p * alpha / 2)) + dy
+    if angular_step is not None:
+        # For angular discretization in the arc section
+        arc_angle = alpha * (1 - p)  # angle covered by the arc section
+        theta = np.linspace(0, arc_angle, num_pts_arc)
+        xbend2 = Rp * np.sin(theta + p * alpha / 2) + dx
+        ybend2 = Rp * (1 - np.cos(theta + p * alpha / 2)) + dy
+    else:
+        s = np.linspace(sp, s0 / 2, num_pts_arc)
+        xbend2 = Rp * np.sin((s - sp) / Rp + p * alpha / 2) + dx
+        ybend2 = Rp * (1 - np.cos((s - sp) / Rp + p * alpha / 2)) + dy
 
     x = np.concatenate([xbend1, xbend2[1:]])
     y = np.concatenate([ybend1, ybend2[1:]])
@@ -1778,7 +1846,8 @@ if __name__ == "__main__":
         radius=5,
         angle=180,
         p=1,
-        use_eff=True,
+        use_eff=False,
+        # angular_step=1
     )
 
     print(p.start_angle, p.end_angle)  # 0, 180
