@@ -2,11 +2,13 @@
 
 from __future__ import annotations
 
+from typing import Any
+
 import numpy as np
 import numpy.typing as npt
 
 import gdsfactory as gf
-from gdsfactory.port import Port
+from gdsfactory.typings import Port
 
 
 def _get_rotated_basis(
@@ -47,53 +49,58 @@ def route_quad(
         c = gf.Component()
         pad1 = c << gf.components.pad(size=(50, 50))
         pad2 = c << gf.components.pad(size=(10, 10))
-        pad2.dmovex(100)
-        pad2.dmovey(50)
-        route_gnd = c << gf.routing.route_quad(
+        pad2.movex(100)
+        pad2.movey(50)
+        gf.routing.route_quad(
+            c,
             pad1.ports["e2"],
             pad2.ports["e4"],
             width1=None,
             width2=None,
         )
-        c.show()
         c.plot()
 
     """
 
     def get_port_edges(
         port: Port, width: float
-    ) -> tuple[npt.NDArray[np.float64], npt.NDArray[np.float64]]:
+    ) -> tuple[npt.NDArray[np.floating[Any]], npt.NDArray[np.floating[Any]]]:
         _, e1 = _get_rotated_basis(port.orientation)
-        pt1 = port.dcenter + e1 * width / 2
-        pt2 = port.dcenter - e1 * width / 2
+        pt1 = port.center + e1 * width / 2
+        pt2 = port.center - e1 * width / 2
         return pt1, pt2
 
     if width1 is None:
-        width1 = port1.dwidth
+        width1 = port1.width
     if width2 is None:
-        width2 = port2.dwidth
+        width2 = port2.width
     vertices = np.array(get_port_edges(port1, width1) + get_port_edges(port2, width2))
     center = np.mean(vertices, axis=0)
     displacements = vertices - center
     # sort vertices by angle from center of quadrilateral to make convex polygon
     angles = np.array([np.arctan2(disp[0], disp[1]) for disp in displacements])
-    vertices = [vert for _, vert in sorted(zip(angles, vertices), key=lambda x: x[0])]
+    sorted_vertices: npt.NDArray[np.floating[Any]] = np.array(
+        [vert for _, vert in sorted(zip(angles, vertices), key=lambda x: x[0])],
+        dtype=np.float64,
+    )
 
     if manhattan_target_step:
         component.add_polygon(
-            vertices,
+            sorted_vertices,
             layer=layer,
         )
     else:
-        component.add_polygon(points=vertices, layer=layer)
+        component.add_polygon(points=sorted_vertices, layer=layer)
 
 
 if __name__ == "__main__":
+    from gdsfactory.components import pad
+
     c = gf.Component()
-    pad1 = c << gf.components.pad(size=(50, 50))
-    pad2 = c << gf.components.pad(size=(10, 10))
-    pad2.dmovex(100)
-    pad2.dmovey(50)
+    pad1 = c << pad(size=(50, 50))
+    pad2 = c << pad(size=(10, 10))
+    pad2.movex(100)
+    pad2.movey(50)
     route_quad(
         c,
         pad1.ports["e2"],
@@ -103,11 +110,11 @@ if __name__ == "__main__":
         manhattan_target_step=0.1,
     )
 
-    # c = gf.Component("route")
+    # c = gf.Component(name="route")
     # pad1 = c << gf.components.pad(size=(50, 50))
     # pad2 = c << gf.components.pad(size=(10, 10))
-    # pad2.dmovex(100)
-    # pad2.dmovey(50)
+    # pad2.movex(100)
+    # pad2.movey(50)
     # route_gnd = c << route_quad(
     #     pad1.ports["e2"],
     #     pad2.ports["e4"],
