@@ -6,7 +6,7 @@ if __name__ == "__main__":
     ref2 = c.add_ref(gf.components.text("Hello", size=10, layer=(2, 0)))
     ref3 = c.add_ref(gf.components.text("world", size=10, layer=(2, 0)))
 
-    ref1.dxmax = ref2.dxmin - 5
-    ref3.dxmin = ref2.dxmax + 2
-    ref3.drotate(30)
+    ref1.xmax = ref2.xmin - 5
+    ref3.xmin = ref2.xmax + 2
+    ref3.rotate(30)
     c.show()
