@@ -11,7 +11,7 @@ from __future__ import annotations
 import gdsfactory as gf
 
 if __name__ == "__main__":
-    c = gf.Component("lidar")
+    c = gf.Component(name="lidar")
     noutputs = 2**2
     antenna_pitch = 2.0
     splitter_tree_spacing = (50.0, 70.0)
@@ -23,12 +23,14 @@ if __name__ == "__main__":
 
     # phase Shifters
     phase_shifter = gf.components.straight_heater_meander()
-    phase_shifter_optical_ports = []
+    phase_shifter_extended = gf.components.extend_ports(phase_shifter, length=20)
+    phase_shifter_optical_ports: list[gf.Port] = []
 
     for i, port in enumerate(
         splitter_tree.ports.filter(orientation=0, port_type="optical")
     ):
-        ref = c.add_ref(phase_shifter, name=f"ps{i}")
+        ref = c.add_ref(phase_shifter_extended, name=f"ps{i}")
+        ref.mirror()
         ref.connect("o1", port)
         c.add_ports(ref.ports.filter(port_type="electrical"), prefix=f"ps{i}")
         phase_shifter_optical_ports.append(ref.ports["o2"])
@@ -38,11 +40,12 @@ if __name__ == "__main__":
         gf.components.dbr(n=200),
         rows=noutputs,
         columns=1,
-        spacing=(0, antenna_pitch),
+        column_pitch=0,
+        row_pitch=antenna_pitch,
         centered=True,
     )
-    antennas.dxmin = ref.dxmax + 100
-    antennas.dy = 0
+    antennas.xmin = ref.xmax + 100
+    antennas.y = 0
 
     routes = gf.routing.route_bundle(
         c,
@@ -50,6 +53,7 @@ if __name__ == "__main__":
         ports2=phase_shifter_optical_ports,
         radius=5,
         sort_ports=True,
+        cross_section="strip",
     )
 
     c.show()
